.. _quick_tutorial:

==========================
Quick Tutorial for Pyramid
==========================

Pyramid is a web framework for Python 2 and 3. This tutorial gives a
Python 3/2-compatible, high-level tour of the major features.

This hands-on tutorial covers "a little about a lot": practical
introductions to the most common facilities. Fun, fast-paced, and most
certainly not aimed at experts of the Pyramid web framework.

Contents
========

.. toctree::
    :maxdepth: 1

    requirements
    tutorial_approach
    scaffolds
    hello_world
    package
    ini
    debugtoolbar
    unit_testing
    functional_testing
    views
    templating
    view_classes
    request_response
    routing
    jinja2
    static_assets
    json
    more_view_classes
    logging
    sessions
    forms
    databases
    authentication
    authorization

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
